==> apache-camel-4.12.0-src.zip: apache-camel-4.12.0/components/camel-spring-parent/camel-spring-xml/src/test/java/org/apache/camel/spring/processor/SpringFilterNoChildTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.processor;

import org.apache.camel.FailedToCreateRouteException;
import org.apache.camel.spring.SpringTestSupport;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractXmlApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.fail;

public class SpringFilterNoChildTest extends SpringTestSupport {

    @Override
    protected AbstractXmlApplicationContext createApplicationContext() {
        try {
            new ClassPathXmlApplicationContext("org/apache/camel/spring/processor/filterNoChild.xml");
            fail("Should thrown an exception");
        } catch (Exception e) {
            FailedToCreateRouteException cause = assertIsInstanceOf(FailedToCreateRouteException.class, e);
            IllegalArgumentException iae = assertIsInstanceOf(IllegalArgumentException.class, cause.getCause());
            assertEquals("Definition has no children on Filter[xpath{$foo = 'bar'} -> []]", iae.getMessage());
        }
        return null;
    }

    @Override
    @BeforeEach
    public void setUp() throws Exception {
        // must override as there is no valid spring xml file
        createApplicationContext();
    }

    @Test
    public void testFilterNoOutput() throws Exception {
        // noop
    }

}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-spring-parent/camel-spring-xml/src/test/java/org/apache/camel/spring/processor/SpringFilterNoChildTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.processor;

import org.apache.camel.FailedToCreateRouteException;
import org.apache.camel.spring.SpringTestSupport;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractXmlApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

public class SpringFilterNoChildTest extends SpringTestSupport {

    @Override
    protected AbstractXmlApplicationContext createApplicationContext() {
        try (ClassPathXmlApplicationContext x
                = new ClassPathXmlApplicationContext("org/apache/camel/spring/processor/filterNoChild.xml")) {
            fail("Should thrown an exception");
        } catch (Exception e) {
            FailedToCreateRouteException cause = assertIsInstanceOf(FailedToCreateRouteException.class, e);
            IllegalArgumentException iae = assertIsInstanceOf(IllegalArgumentException.class, cause.getCause());
            assertEquals("Definition has no children on Filter[xpath{$foo = 'bar'} -> []]", iae.getMessage());
        }
        return null;
    }

    @Override
    @BeforeEach
    public void setUp() throws Exception {
        // must override as there is no valid spring xml file
        createApplicationContext();
    }

    @Test
    public void testFilterNoOutput() throws Exception {
        // No op test: we test that the context is setup properly.
        assertTrue(true);
    }

}
